==> jc-1.4.0.tar.gz: soot/jimple/toolkits/annotation/defs/ReachingDefsTagger.h <==
// public class soot.jimple.toolkits.annotation.defs.ReachingDefsTagger

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a76a7734eb62f430 soot_BodyTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class 2dddca24fed89a7c soot_jimple_toolkits_annotation_defs_ReachingDefsTagger

// header file dependencies
// @dep_header soot_BodyTransformer

#include "soot/BodyTransformer.h"

#ifndef _JC_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger_H_
#define _JC_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$sub_refs	_jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$refs	_jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$nonrefs	_jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$object	_jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$object;

typedef const struct _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$vmethods	_jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$vtable	_jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$vtype	_jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$method$internalTransform$9abd4924859b68a3(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$method_info$internalTransform$9abd4924859b68a3;

// Static methods
extern struct _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$object *_jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$method$v$ec14bb5befcc03ca(_jc_env *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$vmethods {
	void	(*internalTransform$9abd4924859b68a3)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_BodyTransformer$vmethods	soot_BodyTransformer;
	_jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$vmethods	soot_jimple_toolkits_annotation_defs_ReachingDefsTagger;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$refs {
    _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$sub_refs	soot_jimple_toolkits_annotation_defs_ReachingDefsTagger;
    _jc_soot_BodyTransformer$sub_refs	soot_BodyTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_BodyTransformer$sub_nonrefs	soot_BodyTransformer;
    _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$sub_nonrefs	soot_jimple_toolkits_annotation_defs_ReachingDefsTagger;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$object {
	_jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$vtype _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_defs_ReachingDefsTagger, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/annotation/defs/ReachingDefsTagger.h <==
// public class soot.jimple.toolkits.annotation.defs.ReachingDefsTagger

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a76a7734eb62f430 soot_BodyTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class 2dddca24fed89a7c soot_jimple_toolkits_annotation_defs_ReachingDefsTagger

// header file dependencies
// @dep_header soot_BodyTransformer

#include "soot/BodyTransformer.h"

#ifndef _JC_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger_H_
#define _JC_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$sub_refs	_jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$refs	_jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$nonrefs	_jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$object	_jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$object;

typedef const struct _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$vmethods	_jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$vtable	_jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$vtype	_jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$method$internalTransform$9abd4924859b68a3(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$method_info$internalTransform$9abd4924859b68a3;

// Static methods
extern struct _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$object *_jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$method$v$ec14bb5befcc03ca(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$vmethods {
	void	(*internalTransform$9abd4924859b68a3)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_BodyTransformer$vmethods	soot_BodyTransformer;
	_jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$vmethods	soot_jimple_toolkits_annotation_defs_ReachingDefsTagger;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$refs {
    _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$sub_refs	soot_jimple_toolkits_annotation_defs_ReachingDefsTagger;
    _jc_soot_BodyTransformer$sub_refs	soot_BodyTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_BodyTransformer$sub_nonrefs	soot_BodyTransformer;
    _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$sub_nonrefs	soot_jimple_toolkits_annotation_defs_ReachingDefsTagger;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$object {
	_jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$vtype _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_defs_ReachingDefsTagger, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_defs_ReachingDefsTagger_H_ */
